@@ -22,15 +22,15 @@ from nnunet.network_architecture.generic_UNet import Generic_UNet
 from nnunet.paths import *
 
 
-class ExperimentPlanner3D_v21_16GB(ExperimentPlanner3D_v21):
+class ExperimentPlanner3D_v21_11GB(ExperimentPlanner3D_v21):
     """
-    Same as ExperimentPlanner3D_v21, but designed to fill 16GB in fp16
+    Same as ExperimentPlanner3D_v21, but designed to fill a RTX2080 ti (11GB) in fp16
     """
     def __init__(self, folder_with_cropped_data, preprocessed_output_folder):
-        super(ExperimentPlanner3D_v21_16GB, self).__init__(folder_with_cropped_data, preprocessed_output_folder)
-        self.data_identifier = "nnUNetData_plans_v2.1_16GB"
+        super(ExperimentPlanner3D_v21_11GB, self).__init__(folder_with_cropped_data, preprocessed_output_folder)
+        self.data_identifier = "nnUNetData_plans_v2.1_big"
         self.plans_fname = join(self.preprocessed_output_folder,
-                                "nnUNetPlansv2.1_16GB_plans_3D.pkl")
+                                "nnUNetPlansv2.1_big_plans_3D.pkl")
 
     def get_properties_for_stage(self, current_spacing, original_spacing, original_shape, num_cases,
                                  num_modalities, num_classes):
@@ -61,9 +61,9 @@ class ExperimentPlanner3D_v21_16GB(ExperimentPlanner3D_v21):
                                                              self.unet_featuremap_min_edge_length,
                                                              self.unet_max_numpool)
         #     use_this_for_batch_size_computation_3D = 520000000 # 505789440
-        # typical ExperimentPlanner3D_v21 configurations use ~8.5GB, but here we allow for 16GB
+        # typical ExperimentPlanner3D_v21 configurations use ~8.6GB, but on a 2080ti we have 11. Allow for more space
         # to be used
-        ref = Generic_UNet.use_this_for_batch_size_computation_3D * 16 / 8.5
+        ref = Generic_UNet.use_this_for_batch_size_computation_3D * 11 / 8  # 8 instead of 8.5 because YOLO
         here = Generic_UNet.compute_approx_vram_consumption(new_shp, network_num_pool_per_axis,
                                                             self.unet_base_num_features,
                                                             self.unet_max_num_filters, num_modalities,
