@@ -115,11 +115,11 @@ def resample_data_or_seg(data, new_shape, is_seg, axis=None, order=3, do_separat
     :param axis:
     :param order:
     :param do_separate_z:
-    :param cval:
     :param order_z: only applies if do_separate_z is True
     :return:
     """
     assert len(data.shape) == 4, "data must be (c, x, y, z)"
+    assert len(new_shape) == len(data.shape) - 1
     if is_seg:
         resize_fn = resize_segmentation
         kwargs = OrderedDict()
@@ -147,12 +147,11 @@ def resample_data_or_seg(data, new_shape, is_seg, axis=None, order=3, do_separat
                 reshaped_data = []
                 for slice_id in range(shape[axis]):
                     if axis == 0:
-                        reshaped_data.append(resize_fn(data[c, slice_id], new_shape_2d, order, **kwargs))
+                        reshaped_data.append(resize_fn(data[c, slice_id], new_shape_2d, order, **kwargs).astype(dtype_data))
                     elif axis == 1:
-                        reshaped_data.append(resize_fn(data[c, :, slice_id], new_shape_2d, order, **kwargs))
+                        reshaped_data.append(resize_fn(data[c, :, slice_id], new_shape_2d, order, **kwargs).astype(dtype_data))
                     else:
-                        reshaped_data.append(resize_fn(data[c, :, :, slice_id], new_shape_2d, order,
-                                                       **kwargs))
+                        reshaped_data.append(resize_fn(data[c, :, :, slice_id], new_shape_2d, order, **kwargs).astype(dtype_data))
                 reshaped_data = np.stack(reshaped_data, axis)
                 if shape[axis] != new_shape[axis]:
 
@@ -172,7 +171,7 @@ def resample_data_or_seg(data, new_shape, is_seg, axis=None, order=3, do_separat
                     coord_map = np.array([map_rows, map_cols, map_dims])
                     if not is_seg or order_z == 0:
                         reshaped_final_data.append(map_coordinates(reshaped_data, coord_map, order=order_z,
-                                                                   mode='nearest')[None])
+                                                                   mode='nearest')[None].astype(dtype_data))
                     else:
                         unique_labels = np.unique(reshaped_data)
                         reshaped = np.zeros(new_shape, dtype=dtype_data)
@@ -182,15 +181,15 @@ def resample_data_or_seg(data, new_shape, is_seg, axis=None, order=3, do_separat
                                 map_coordinates((reshaped_data == cl).astype(float), coord_map, order=order_z,
                                                 mode='nearest'))
                             reshaped[reshaped_multihot > 0.5] = cl
-                        reshaped_final_data.append(reshaped[None])
+                        reshaped_final_data.append(reshaped[None].astype(dtype_data))
                 else:
-                    reshaped_final_data.append(reshaped_data[None])
+                    reshaped_final_data.append(reshaped_data[None].astype(dtype_data))
             reshaped_final_data = np.vstack(reshaped_final_data)
         else:
             print("no separate z, order", order)
             reshaped = []
             for c in range(data.shape[0]):
-                reshaped.append(resize_fn(data[c], new_shape, order, **kwargs)[None])
+                reshaped.append(resize_fn(data[c], new_shape, order, **kwargs)[None].astype(dtype_data))
             reshaped_final_data = np.vstack(reshaped)
         return reshaped_final_data.astype(dtype_data)
     else:
@@ -212,6 +211,8 @@ class GenericPreprocessor(object):
         self.use_nonzero_mask = use_nonzero_mask
 
         self.resample_separate_z_anisotropy_threshold = RESAMPLING_SEPARATE_Z_ANISO_THRESHOLD
+        self.resample_order_data = 3
+        self.resample_order_seg = 1
 
     @staticmethod
     def load_cropped(cropped_output_dir, case_identifier):
@@ -246,7 +247,8 @@ class GenericPreprocessor(object):
         # remove nans
         data[np.isnan(data)] = 0
 
-        data, seg = resample_patient(data, seg, np.array(original_spacing_transposed), target_spacing, 3, 1,
+        data, seg = resample_patient(data, seg, np.array(original_spacing_transposed), target_spacing,
+                                     self.resample_order_data, self.resample_order_seg,
                                      force_separate_z=force_separate_z, order_z_data=0, order_z_seg=0,
                                      separate_z_anisotropy_threshold=self.resample_separate_z_anisotropy_threshold)
         after = {
@@ -294,6 +296,7 @@ class GenericPreprocessor(object):
                 if use_nonzero_mask[c]:
                     data[c][seg[-1] < 0] = 0
             elif scheme == 'noNorm':
+                print('no intensity normalization')
                 pass
             else:
                 if use_nonzero_mask[c]:
@@ -396,6 +399,14 @@ class GenericPreprocessor(object):
             p.join()
 
 
+class GenericPreprocessor_linearResampling(GenericPreprocessor):
+    def __init__(self, normalization_scheme_per_modality, use_nonzero_mask, transpose_forward: (tuple, list),
+                 intensityproperties=None):
+        super().__init__(normalization_scheme_per_modality, use_nonzero_mask, transpose_forward, intensityproperties)
+        self.resample_order_data = 1
+        self.resample_order_seg = 1
+
+
 class Preprocessor3DDifferentResampling(GenericPreprocessor):
     def resample_and_normalize(self, data, target_spacing, properties, seg=None, force_separate_z=None):
         """
@@ -679,6 +690,89 @@ class PreprocessorFor2D(GenericPreprocessor):
         return data, seg, properties
 
 
+class PreprocessorFor2D_edgeLength512(PreprocessorFor2D):
+    target_edge_size = 512
+
+    def resample_and_normalize(self, data, target_spacing, properties, seg=None, force_separate_z=None):
+        original_spacing_transposed = np.array(properties["original_spacing"])[self.transpose_forward]
+        before = {
+            'spacing': properties["original_spacing"],
+            'spacing_transposed': original_spacing_transposed,
+            'data.shape (data is transposed)': data.shape
+        }
+        data_shape = data.shape[-2:]
+        smaller_edge = min(data_shape)
+        target_edge_size = self.target_edge_size
+        scale_factor = target_edge_size / smaller_edge
+        new_shape = [1] + [int(np.round(i * scale_factor)) for i in data_shape]
+        print(new_shape)
+
+        data = resample_data_or_seg(data, new_shape, False, None, 3, False, 0)
+        seg = resample_data_or_seg(seg, new_shape, True, None, 1, False, 0)
+
+        after = {
+            'spacing': 'None',
+            'data.shape (data is resampled)': data.shape
+        }
+        print("before:", before, "\nafter: ", after, "\n")
+
+        if seg is not None:  # hippocampus 243 has one voxel with -2 as label. wtf?
+            seg[seg < -1] = 0
+
+        properties["size_after_resampling"] = data[0].shape
+        properties["spacing_after_resampling"] = target_spacing
+        use_nonzero_mask = self.use_nonzero_mask
+
+        assert len(self.normalization_scheme_per_modality) == len(data), "self.normalization_scheme_per_modality " \
+                                                                         "must have as many entries as data has " \
+                                                                         "modalities"
+        assert len(self.use_nonzero_mask) == len(data), "self.use_nonzero_mask must have as many entries as data" \
+                                                        " has modalities"
+
+        print("normalization...")
+
+        for c in range(len(data)):
+            scheme = self.normalization_scheme_per_modality[c]
+            if scheme == "CT":
+                # clip to lb and ub from train data foreground and use foreground mn and sd from training data
+                assert self.intensityproperties is not None, "ERROR: if there is a CT then we need intensity properties"
+                mean_intensity = self.intensityproperties[c]['mean']
+                std_intensity = self.intensityproperties[c]['sd']
+                lower_bound = self.intensityproperties[c]['percentile_00_5']
+                upper_bound = self.intensityproperties[c]['percentile_99_5']
+                data[c] = np.clip(data[c], lower_bound, upper_bound)
+                data[c] = (data[c] - mean_intensity) / std_intensity
+                if use_nonzero_mask[c]:
+                    data[c][seg[-1] < 0] = 0
+            elif scheme == "CT2":
+                # clip to lb and ub from train data foreground, use mn and sd form each case for normalization
+                assert self.intensityproperties is not None, "ERROR: if there is a CT then we need intensity properties"
+                lower_bound = self.intensityproperties[c]['percentile_00_5']
+                upper_bound = self.intensityproperties[c]['percentile_99_5']
+                mask = (data[c] > lower_bound) & (data[c] < upper_bound)
+                data[c] = np.clip(data[c], lower_bound, upper_bound)
+                mn = data[c][mask].mean()
+                sd = data[c][mask].std()
+                data[c] = (data[c] - mn) / sd
+                if use_nonzero_mask[c]:
+                    data[c][seg[-1] < 0] = 0
+            elif scheme == 'noNorm':
+                pass
+            else:
+                if use_nonzero_mask[c]:
+                    mask = seg[-1] >= 0
+                else:
+                    mask = np.ones(seg.shape[1:], dtype=bool)
+                data[c][mask] = (data[c][mask] - data[c][mask].mean()) / (data[c][mask].std() + 1e-8)
+                data[c][mask == 0] = 0
+        print("normalization done")
+        return data, seg, properties
+
+
+class PreprocessorFor2D_edgeLength768(PreprocessorFor2D_edgeLength512):
+    target_edge_size = 768
+
+
 class PreprocessorFor3D_LeaveOriginalZSpacing(GenericPreprocessor):
     """
     3d_lowres and 3d_fullres are not resampled along z!
@@ -854,35 +948,3 @@ class PreprocessorFor3D_NoResampling(GenericPreprocessor):
                 data[c][mask == 0] = 0
         return data, seg, properties
 
-
-class PreprocessorFor2D_noNormalization(GenericPreprocessor):
-    def resample_and_normalize(self, data, target_spacing, properties, seg=None, force_separate_z=None):
-        original_spacing_transposed = np.array(properties["original_spacing"])[self.transpose_forward]
-        before = {
-            'spacing': properties["original_spacing"],
-            'spacing_transposed': original_spacing_transposed,
-            'data.shape (data is transposed)': data.shape
-        }
-        target_spacing[0] = original_spacing_transposed[0]
-        data, seg = resample_patient(data, seg, np.array(original_spacing_transposed), target_spacing, 3, 1,
-                                     force_separate_z=force_separate_z, order_z_data=0, order_z_seg=0,
-                                     separate_z_anisotropy_threshold=self.resample_separate_z_anisotropy_threshold)
-        after = {
-            'spacing': target_spacing,
-            'data.shape (data is resampled)': data.shape
-        }
-        print("before:", before, "\nafter: ", after, "\n")
-
-        if seg is not None:  # hippocampus 243 has one voxel with -2 as label. wtf?
-            seg[seg < -1] = 0
-
-        properties["size_after_resampling"] = data[0].shape
-        properties["spacing_after_resampling"] = target_spacing
-        use_nonzero_mask = self.use_nonzero_mask
-
-        assert len(self.normalization_scheme_per_modality) == len(data), "self.normalization_scheme_per_modality " \
-                                                                         "must have as many entries as data has " \
-                                                                         "modalities"
-        assert len(self.use_nonzero_mask) == len(data), "self.use_nonzero_mask must have as many entries as data" \
-                                                        " has modalities"
-        return data, seg, properties
\ No newline at end of file
