@@ -492,7 +492,7 @@ class nnUNetTrainerV2_DDP(nnUNetTrainerV2):
         my_keys = all_keys[self.local_rank::dist.get_world_size()]
         # we cannot simply iterate over all_keys because we need to know pred_gt_tuples and valid_labels of all cases
         # for evaluation (which is done by local rank 0)
-        for k in my_keys:
+        for k in all_keys:
             properties = load_pickle(self.dataset[k]['properties_file'])
             fname = properties['list_of_data_files'][0].split("/")[-1][:-12]
             pred_gt_tuples.append([join(output_folder, fname + ".nii.gz"),
@@ -521,9 +521,9 @@ class nnUNetTrainerV2_DDP(nnUNetTrainerV2):
                     else:
                         softmax_fname = None
 
-                    """There is a problem with python process communication that prevents us from communicating obejcts
+                    """There is a problem with python process communication that prevents us from communicating objects
                     larger than 2 GB between processes (basically when the length of the pickle string that will be sent is
-                    communicated by the multiprocessing.Pipe object then the placeholder (\%i I think) does not allow for long
+                    communicated by the multiprocessing.Pipe object then the placeholder (I think) does not allow for long
                     enough strings (lol). This could be fixed by changing i to l (for long) but that would require manually
                     patching system python code. We circumvent that problem here by saving softmax_pred to a npy file that will
                     then be read (and finally deleted) by the Process. save_segmentation_nifti_from_softmax can take either
@@ -641,7 +641,7 @@ class nnUNetTrainerV2_DDP(nnUNetTrainerV2):
 
         new_state_dict = OrderedDict()
         curr_state_dict_keys = list(self.network.state_dict().keys())
-        # if state dict comes form nn.DataParallel but we use non-parallel model here then the state dict keys do not
+        # if state dict comes from nn.DataParallel but we use non-parallel model here then the state dict keys do not
         # match. Use heuristic to make it match
         for k, value in checkpoint['state_dict'].items():
             key = k
